@@ -224,9 +224,10 @@ class ConfigExternalSources(ConfigSourceBase):
 
 
 class ConfigManager(object):
-    def __init__(self, prefix, legacy, excluded):
+    def __init__(self, prefix, legacy, excluded, appname=None):
         self._prefix = prefix
         self._excluded = excluded
+        self._appname = appname
         self._instance_config = None
         self._local_config = None
         self._external_configs: ConfigExternalSources = None
@@ -310,6 +311,10 @@ class ConfigManager(object):
                          "".format(self.EXTERNAL_CONFIG_SOURCES))
             self._external_configs = ConfigExternalSources(self.EXTERNAL_CONFIG_SOURCES)
 
+    @property
+    def APPNAME(self):
+        return self._appname
+
     @property
     def INSTANCE_CONFIG(self):
         return self._instance_config
